@@ -1,15 +1,6 @@
 #: Okay
 def ok():
     pass
-#: N802
-def __bad():
-    pass
-#: N802
-def bad__():
-    pass
-#: N802
-def __bad__():
-    pass
 #: Okay
 def _ok():
     pass
@@ -25,7 +16,10 @@ def go_od_():
 #: Okay
 def _go_od_():
     pass
-#: N802
+#: N802:1:5
+def NotOK():
+    pass
+#: Okay(--ignore-names=NotOK)
 def NotOK():
     pass
 #: Okay
@@ -47,11 +41,10 @@ class ClassName(object):
 class ClassName(object):
     def notOk(self):
         pass
-#: N802
+#: Okay(--ignore-names=notOk)
 class ClassName(object):
-    def method(self):
-        def __bad():
-            pass
+    def notOk(self):
+        pass
 #: Okay
 def setUp():
     pass
@@ -70,3 +63,5 @@ class TestCase:
         pass
     def tearDownClass(self):
         pass
+    def setUpTestData(self):
+        pass
