@@ -37,10 +37,25 @@ def b12(*BAD):
 #: N803
 def b13(BAD, *VERYBAD, **EXTRABAD):
     pass
-#: N803
+#: N803:1:9
 def b14(BAD):
     pass
-#: N803
+#: Okay
+def b15(_):
+    pass
+#: Okay
+def b16(_a):
+    pass
+#: Okay
+def b17(a, _):
+    pass
+#: Okay
+def b18(a, *_):
+    pass
+#: Okay
+def b19(a, **_):
+    pass
+#: N803:2:24
 class Test(object):
     def __init__(self, BAD):
         pass
@@ -48,3 +63,12 @@ class Test(object):
     @classmethod
     def test(cls, BAD):
         pass
+#: Okay(--ignore-names=I)
+def f(I):
+    I.think_therefore_i_am
+#: Okay(--ignore-names=I)
+def f(*I):
+    I[0].think_therefore_i_am
+#: Okay(--ignore-names=I)
+def f(*I):
+    I[''].think_therefore_i_am
